<?php

namespace Drupal\feature_toggle\Event;

use Symfony\Contracts\EventDispatcher\Event;
use Drupal\feature_toggle\FeatureInterface;

/**
 * Feature Update Event class.
 */
class FeatureUpdateEvent extends Event {

  /**
   * FeatureUpdate constructor.
   *
   * @param \Drupal\feature_toggle\FeatureInterface $feature
   *   The updated feature.
   * @param bool $status
   *   The new feature status.
   */
  public function __construct(
    protected FeatureInterface $feature,
    protected bool $status,
  ) {}

  /**
   * Returns the feature.
   *
   * @return \Drupal\feature_toggle\FeatureInterface
   *   The feature triggering the event.
   */
  public function feature(): FeatureInterface {
    return $this->feature;
  }

  /**
   * Returns the status.
   *
   * @return bool
   *   The feature status.
   */
  public function status(): bool {
    return $this->status;
  }

}
