<?php

namespace Drupal\feature_toggle;

use Drupal\Core\Cache\Cache;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\KeyValueStore\KeyValueFactoryInterface;
use Drupal\feature_toggle\Event\FeatureUpdateEvent;
use Drupal\feature_toggle\Event\FeatureUpdateEvents;
use Symfony\Component\DependencyInjection\Attribute\Autowire;
use Symfony\Contracts\EventDispatcher\EventDispatcherInterface;

/**
 * Service class for FeatureStatus logic.
 */
class FeatureStatus implements FeatureStatusInterface {

  use FeatureUtilsTrait;

  /**
   * Constructs a new FeatureToggleStatus object.
   */
  public function __construct(
    #[Autowire(service: 'keyvalue')]
    protected KeyValueFactoryInterface $keyValueFactory,
    protected ConfigFactoryInterface $config,
    protected EventDispatcherInterface $eventDispatcher,
  ) {}

  /**
   * {@inheritdoc}
   */
  public function getStatus(string $name): bool {
    $flags = $this->getStatusFlags();
    return !empty($flags[$name]);
  }

  /**
   * {@inheritdoc}
   */
  public function setStatus(FeatureInterface $feature, bool $status): void {
    $flags = $this->getStatusFlags();
    $flags[$feature->name()] = $status;
    $this->saveStatusFlags($flags);
    $this->dispatch($feature, $status);
    Cache::invalidateTags([
      'feature_toggle_list',
      'feature_toggle:' . $feature->name(),
    ]);
  }

  /**
   * Dispatches the Feature Update events.
   *
   * @param FeatureInterface $feature
   *   The updated feature.
   * @param bool $status
   *   The new status.
   */
  protected function dispatch(FeatureInterface $feature, bool $status): void {
    $event = new FeatureUpdateEvent($feature, $status);
    $this->eventDispatcher->dispatch($event, FeatureUpdateEvents::UPDATE);
    $this->eventDispatcher->dispatch($event, FeatureUpdateEvents::UPDATE . '.' . $feature->name());
  }

}
