<?php

namespace Drupal\feature_toggle;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\KeyValueStore\KeyValueFactoryInterface;
use Symfony\Component\DependencyInjection\Attribute\Autowire;

/**
 * Provides convenience methods for feature toggle services.
 */
trait FeatureUtilsTrait {

  /**
   * Constructs a new FeatureUtilsTrait object.
   */
  public function __construct(
    #[Autowire(service: 'keyvalue')]
    protected KeyValueFactoryInterface $keyValueFactory,
    protected ConfigFactoryInterface $config,
  ) {
  }

  /**
   * Returns the list of features.
   *
   * @return array
   *   The list of features in the system.
   */
  protected function loadFeatures(): array {
    // Tricky integration of overridden features in settings.php file.
    $mutable = $this->config->getEditable('feature_toggle.features')->get('features') ?? [];
    $immutable = $this->config->get('feature_toggle.features')->get('features') ?? [];
    return array_merge($mutable, $immutable);
  }

  /**
   * Saves the features array.
   *
   * @param array $features
   *   The features array.
   */
  protected function saveFeatures(array $features): void {
    $this->config->getEditable('feature_toggle.features')->set('features', $features)->save();
  }

  /**
   * Returns the system status flags.
   *
   * @return array
   *   The status flags array.
   */
  protected function getStatusFlags(): array {
    $features = $this->keyValueFactory->get('feature_toggle')->get('flags', []);
    return $features;
  }

  /**
   * Saves the status flags array.
   *
   * @param array $flags
   *   The status flags array.
   */
  protected function saveStatusFlags(array $flags): void {
    $this->keyValueFactory->get('feature_toggle')->set('flags', $flags);
  }

}
