<?php

declare(strict_types=1);

namespace Drupal\feature_toggle\Hook;

use Drupal\Core\Hook\Attribute\Hook;
use Drupal\feature_toggle\FeatureManagerInterface;
use Drupal\feature_toggle\FeatureStatusInterface;

/**
 * Hook implementations for Feature Toggle.
 */
class FeatureToggleHooks {

  /**
   * Constructs a new FeatureToggleHooks object.
   *
   * @param \Drupal\feature_toggle\FeatureManagerInterface $featureManager
   *   The feature manager.
   * @param \Drupal\feature_toggle\FeatureStatusInterface $featureStatus
   *   The feature status.
   */
  public function __construct(
    protected FeatureManagerInterface $featureManager,
    protected FeatureStatusInterface $featureStatus,
  ) {}

  /**
   * Implements hook_theme().
   */
  #[Hook('theme')]
  public function theme(): array {
    return [
      'feature_toggle_form' => [
        'render element' => 'form',
        'file' => 'feature_toggle.theme.inc',
      ],
    ];
  }

  /**
   * Implements hook_page_attachments().
   */
  #[Hook('page_attachments')]
  public function pageAttachments(array &$attachments): void {
    $features = $this->featureManager->getFeatures();
    $enabled = [];
    foreach ($features as $feature) {
      /** @var \Drupal\feature_toggle\Feature $feature */
      if ($this->featureStatus->getStatus($feature->name())) {
        $enabled[] = $feature->name();
      }
    }
    $attachments['#attached']['drupalSettings']['feature_toggle']['enabled'] = $enabled;
  }

}
