<?php

namespace Drupal\feature_toggle\Plugin\views\access;

use Drupal\Core\Cache\Cache;
use Drupal\Core\Cache\CacheableDependencyInterface;
use Drupal\views\Plugin\views\access\AccessPluginBase;

/**
 * Access plugin that provides feature-based access control.
 *
 * @ingroup views_access_plugins
 *
 * @ViewsAccess(
 *   id = "feature_toggle_feature",
 *   title = @Translation("Feature (Unrestricted)"),
 *   help = @Translation("Access will be granted to users based on configured feature.")
 * )
 */
class Feature extends AccessPluginBase implements CacheableDependencyInterface {

  use ViewsFeatureAccessTrait;

  /**
   * {@inheritdoc}
   */
  protected $usesOptions = TRUE;

  /**
   * {@inheritdoc}
   */
  public function summaryTitle() {
    $feature = $this->featureManager()->getFeature($this->options['feature_name']);
    return $this->t('@feature (@status)', [
      '@feature' => empty($this->options['feature_name']) ? $this->t('None') :
      (isset($feature) ? $feature->label() : $this->options['feature_name']),
      '@status' => empty($this->options['status']) ? $this->t('N/A') :
      (isset($this->options['status']) ? $this->t('Enabled') : $this->t('Disabled')),
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge() {
    return Cache::PERMANENT;
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheContexts() {
    return [];
  }

}
