<?php

declare(strict_types=1);

namespace Drupal\feature_toggle\Plugin\views\access;

use Drupal\user\Plugin\views\access\Permission;

/**
 * Access plugin that provides permission&feature-based access control.
 *
 * @ingroup views_access_plugins
 *
 * @ViewsAccess(
 *   id = "feature_toggle_perm_feature",
 *   title = @Translation("Permission + Feature"),
 *   help = @Translation("Access will be granted to users with the specified permission string & Feature status.")
 * )
 */
class PermissionFeature extends Permission {

  use ViewsFeatureAccessTrait;

  /**
   * {@inheritdoc}
   */
  public function summaryTitle() {
    $perm = parent::summaryTitle();

    $feature = $this->featureManager()->getFeature($this->options['feature_name']);
    return $this->t('Permission: %perm, Feature: %feature (%status)', [
      '%perm' => $perm,
      '%feature' => empty($this->options['feature_name']) ? $this->t('None') :
      (isset($feature) ? $feature->label() : $this->options['feature_name']),
      '%status' => empty($this->options['status']) ? $this->t('N/A') :
      (isset($this->options['status']) ? $this->t('Enabled') : $this->t('Disabled')),
    ]);
  }

}
