<?php

declare(strict_types=1);

namespace Drupal\feature_toggle\Plugin\views\access;

use Drupal\user\Plugin\views\access\Role;

/**
 * Access plugin that provides role&tier-based access control.
 *
 * @ingroup views_access_plugins
 *
 * @ViewsAccess(
 *   id = "feature_toggle_role_feature",
 *   title = @Translation("Role + Feature"),
 *   help = @Translation("Access will be granted to users with the specified roles string & Feature status.")
 * )
 */
class RoleFeature extends Role {

  use ViewsFeatureAccessTrait;

  /**
   * {@inheritdoc}
   */
  public function summaryTitle() {
    $roles = parent::summaryTitle();

    $feature = $this->featureManager()->getFeature($this->options['feature_name']);
    return $this->t('Roles: %roles, Feature: %feature (%status)', [
      '%roles' => $roles,
      '%feature' => empty($this->options['feature_name']) ? $this->t('None') :
      (isset($feature) ? $feature->label() : $this->options['feature_name']),
      '%status' => empty($this->options['status']) ? $this->t('N/A') :
      (($this->options['status'] == TRUE) ? $this->t('Enabled') : $this->t('Disabled')),
    ]);

  }

}
